using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace TestHTMLControl
{
    public partial class ConfigureVariableDialog : Form
    {
        private Variable variable;

        public ConfigureVariableDialog()
        {
            InitializeComponent();
        }

        public ConfigureVariableDialog(Variable variable)
        {
            this.variable = variable;
            InitializeComponent();
        }

        private void OnLoad(object sender, EventArgs e)
        {
            if (variable != null)
            {
                lblLabel.Text = variable.Name + ":";

                switch (variable.Type)
                {
                    case "string":
                        lstValue.Visible = false;
                        cbValue.Visible = false;
                        txtValue.Visible = true;
                        txtValue.Text = variable.StringValue;
                        break;
                    case "number":
                        lstValue.Visible = false;
                        cbValue.Visible = false;
                        txtValue.Visible = true;
                        txtValue.Mask = "00000";
                        txtValue.Text = variable.StringValue;
                        break;
                    case "choice":
                        lstValue.Visible = false;
                        cbValue.Visible = true;
                        txtValue.Visible = false;
                        foreach (string key in variable.Choices.Keys)
                        {
                            cbValue.Items.Add(key);
                        }
                        cbValue.SelectedValue = variable.StringValue;
                        break;
                    case "multichoice":
                        lstValue.Visible = true;
                        cbValue.Visible = false;
                        txtValue.Visible = false;
                        foreach (string key in variable.Choices.Keys)
                        {
                            int index = lstValue.Items.Add(key);
                            if (variable.StringValue == key)
                            {
                                lstValue.SetItemChecked(index, true);
                            }
                        }
                        break;
                }
            }
        }

        private void OnSave()
        {
            if (variable != null)
            {
                switch (variable.Type)
                {
                    case "string":
                        variable.Value = txtValue.Text;
                        break;
                    case "number":
                        if (txtValue.Text == null || txtValue.Text.Length == 0)
                            variable.Value = null;
                        else
                            variable.Value = Convert.ToDouble(txtValue.Text);
                        break;
                    case "choice":
                        if (cbValue.SelectedItem != null)
                        {
                            variable.Value = cbValue.SelectedItem.ToString();
                        }
                        else
                        {
                            variable.Value = null;
                        }
                        break;
                    case "multichoice":
                        string v = "";
                        foreach (string chk in lstValue.CheckedItems)
                        {
                            v += chk + ",";
                        }
                        if (v.Length > 0)
                        {
                            v = v.Substring(0, v.Length - 1);
                        }
                        variable.Value = v.Length == 0 ? null : v;
                        break;
                }
            }
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            OnSave();
            this.DialogResult = DialogResult.OK;
            this.Close();
        }
    }
}